@@ -1,5 +1,6 @@
 pompExample <- function (example, ..., show = FALSE, envir = .GlobalEnv) {
     example <- as.character(substitute(example))
+    ep <- paste0("in ",sQuote("pompExample"),": ")
     pomp.dir <- system.file("examples",package="pomp")
     exampleDirs <- getOption("pomp.examples",default=pomp.dir)
     names(exampleDirs) <- exampleDirs
@@ -17,14 +18,19 @@ pompExample <- function (example, ..., show = FALSE, envir = .GlobalEnv) {
                          pattern=paste0(example,".R"),
                          full.names=TRUE),
                   recursive=TRUE)
+        if (length(file)<1) {
+            stop(ep,"cannot find file ",
+                 sQuote(paste0(example,".R")),call.=FALSE)
+        }
         if (length(file)>1) {
-            warning("using ",sQuote(file[1])," from ",sQuote(names(file)[1]))
+            warning(ep,"using ",sQuote(file[1])," from ",sQuote(names(file)[1]),call.=FALSE)
         }
-        objs <- source(file[1],local=evalEnv)
         if (show) {
             file.show(file[1])
             return(invisible(NULL))
-        } else if (is.null(envir)) {
+        }
+        objs <- source(file[1],local=evalEnv)
+        if (is.null(envir)) {
             obj <- setNames(lapply(objs$value,get,envir=evalEnv),objs$value)
         } else if (is.environment(envir)) {
             for (i in seq_along(objs$value)) {
@@ -35,7 +41,7 @@ pompExample <- function (example, ..., show = FALSE, envir = .GlobalEnv) {
             cat("newly created object(s):\n",objs$value,"\n")
             obj <- NULL
         } else {
-            stop(sQuote("envir")," must be an environment or NULL")
+            stop(ep,sQuote("envir")," must be an environment or NULL",call.=FALSE)
         }
         invisible(obj)
     }
